==> ecp_sync_plugin-3.9.2.tar.gz: ios/Classes/OneDQrCodeViewController.swift <==
//
//  OneDQrCodeViewController.swift
//  Alamofire
//
//  Created by VCS on 24/07/19.
//

import UIKit
import Foundation
import AVFoundation

class OneDQrCodeViewController: UIViewController, QRScannerViewDelegate {

     var items = [String]()
     //var delegate:BarcodeScannerViewControllerDelegate!
     var isSingleScan:Bool = true
     var isPlaySound:Bool = true
     var isOnFlase:Bool = true
     var themeColor:String = "#004a96"
      var audioPlayer:AVAudioPlayer!
     @IBOutlet var labCount: UILabel!
     //@IBOutlet var previewView: UIView!
     @IBOutlet weak var scannerView: QRScannerView!
     
     var delegate:BarcodeScannerViewControllerDelegate!
     @IBOutlet var labScanText: UILabel!
     
     var nextBtn : String =  ""
     var scanText : String =  ""
     @IBOutlet var btnNextText: UIButton!
     
        /*  {
          didSet {
               scannerView.delegate = self
          }
     }*/
     
     var qrData: QRData? = nil {
          didSet {
               if qrData != nil {
                    //self.performSegue(withIdentifier: "detailSeuge", sender: self)
                    print(qrData?.codeString)
                    
                    if(!items.contains((qrData?.codeString)!)){
                         items.append((qrData?.codeString)!)
                         do{
                              self.audioPlayer.play()
                         }catch {
                              print("Error getting the audio file")
                         }
                    }
                    
                    self.labCount.text = "\(self.items.count)"
                    print("size:\(items.count)")
                    
                    if !scannerView.isRunning {
                         scannerView.startScanning()
                    }
               }
          }
     }
     
     //var delegate:BarcodeScannerViewControllerDelegate!
     
     override func viewDidLoad() {
          super.viewDidLoad()
          
          // Do any additional setup after loading the view.
          
          scannerView.delegate = self
          
          UIApplication.shared.isIdleTimerDisabled = true
          
          self.navigationController?.navigationBar.barTintColor = hexStringToUIColor(hex: themeColor)
          self.navigationController?.navigationBar.tintColor = UIColor.white
          
          let rectShape = CAShapeLayer()
          rectShape.bounds = self.labCount.frame
          rectShape.position = self.labCount.center
          rectShape.path = UIBezierPath(roundedRect: self.labCount.bounds, byRoundingCorners: [.bottomLeft , .topLeft], cornerRadii: CGSize(width: 20, height: 20)).cgPath
          
          //self.labCount.layer.backgroundColor = hexStringToUIColor(hex: themeColor) as! CGColor
          //Here I'm masking the textView's layer with rectShape layer
          self.labCount.layer.mask = rectShape
          labScanText.text = scanText
          btnNextText.setTitle(nextBtn, for: .normal)
          
          let dev = Bundle.main.path(forResource: "beep_sound", ofType: "mp3")!
          //print(alertSound)
          
          // Removed deprecated use of AVAudioSessionDelegate protocol
          try! AVAudioSession.sharedInstance().setCategory(AVAudioSessionCategoryPlayback)
          try! AVAudioSession.sharedInstance().setActive(true)
          
          audioPlayer = try! AVAudioPlayer(contentsOf: URL(fileURLWithPath: dev))
          audioPlayer.prepareToPlay()
     }
     
     override func viewWillAppear(_ animated: Bool) {
          super.viewWillAppear(animated)
          
          if !scannerView.isRunning {
               scannerView.startScanning()
          }
     }
     
     override func viewWillDisappear(_ animated: Bool) {
          super.viewWillDisappear(animated)
          
          UIApplication.shared.isIdleTimerDisabled = false
          
          if !scannerView.isRunning {
               scannerView.stopScanning()
          }
     }
     
     var isClicked:Bool = false
     
     @IBAction func NextClick(_ sender: UIButton) {
          print("NextClick")
          
          if(isClicked == false){
               
               isClicked = true
               
               let myGroup = DispatchGroup()
               
               myGroup.enter()
               //print("details...")
               if !scannerView.isRunning {
                    scannerView.stopScanning()
               }
               print("scan count:\(self.items.count)")
               let strr:String = jsonData(from: self.items)!
               print("scan json:\(strr)")
               
               self.delegate?.barcodeScannerViewController(self, didScanBarcodeWithResult: strr)
               print("buttonPressed")
               
               myGroup.leave()
               
               /*dispatch_group_notify(myGroup, dispatch_get_main_queue(), {
                self.dismiss(animated: false)
                })*/
               
               myGroup.notify(queue: DispatchQueue.main, execute: {
                    self.isClicked = false
                    self.dismiss(animated: false)
                    
               })
          }
     }
     
     func jsonData(from object:Any) -> String? {
          guard let data = try? JSONSerialization.data(withJSONObject: object, options: []) else {
               return nil
          }
          return String(data: data, encoding: String.Encoding.utf8)
     }
     
     @IBAction func backClick(_ sender: UIBarButtonItem) {
          
          print("backClick")
          if !scannerView.isRunning {
               scannerView.stopScanning()
          }
          self.delegate.barcodeScannerViewController(self, didFailWithErrorCode: "err")
          dismiss(animated: true)
     }
     
     /*
      // MARK: - Navigation
      
      // In a storyboard-based application, you will often want to do a little preparation before navigation
      override func prepare(for segue: UIStoryboardSegue, sender: Any?) {
      // Get the new view controller using segue.destination.
      // Pass the selected object to the new view controller.
      }
      */

     func hexStringToUIColor (hex:String) -> UIColor {
          var cString:String = hex.trimmingCharacters(in: .whitespacesAndNewlines).uppercased()
          
          if (cString.hasPrefix("#")) {
               cString.remove(at: cString.startIndex)
          }
          
          if ((cString.count) != 6) {
               return UIColor.gray
          }
          
          var rgbValue:UInt32 = 0
          Scanner(string: cString).scanHexInt32(&rgbValue)
          
          return UIColor(
               red: CGFloat((rgbValue & 0xFF0000) >> 16) / 255.0,
               green: CGFloat((rgbValue & 0x00FF00) >> 8) / 255.0,
               blue: CGFloat(rgbValue & 0x0000FF) / 255.0,
               alpha: CGFloat(1.0)
          )
     }
     
     func qrScanningDidStop() {
          //let buttonTitle = scannerView.isRunning ? "STOP" : "SCAN"
          //scanButton.setTitle(buttonTitle, for: .normal)
     }
     
     func qrScanningDidFail() {
          //presentAlert(withTitle: "Error", message: "Scanning Failed. Please try again")
          print("Scanning Failed. Please try again")
     }
     
     func qrScanningSucceededWithCode(_ str: String?) {
          self.qrData = QRData(codeString: str)
          print(self.qrData)
     }
}

/*extension OneDQrCodeViewController: QRScannerViewDelegate {
     func qrScanningDidStop() {
          let buttonTitle = scannerView.isRunning ? "STOP" : "SCAN"
          //scanButton.setTitle(buttonTitle, for: .normal)
     }
     
     func qrScanningDidFail() {
          //presentAlert(withTitle: "Error", message: "Scanning Failed. Please try again")
     }
     
     func qrScanningSucceededWithCode(_ str: String?) {
          self.qrData = QRData(codeString: str)
          print(self.qrData)
     }
     
     
     
}*/

==> ecp_sync_plugin-6.8.40.tar.gz: ios/Classes/OneDQrCodeViewController.swift <==
//
//  OneDQrCodeViewController.swift
//  Alamofire
//
//  Created by VCS on 24/07/19.
//

import UIKit
import Foundation
import AVFoundation

class OneDQrCodeViewController: UIViewController, QRScannerViewDelegate {

     var items = [String]()
     //var delegate:BarcodeScannerViewControllerDelegate!
     var isSingleScan:Bool = true
     var isPlaySound:Bool = true
     var isOnFlase:Bool = true
     var themeColor:String = "#004a96"
      var audioPlayer:AVAudioPlayer!
     @IBOutlet var labCount: UILabel!
     //@IBOutlet var previewView: UIView!
     @IBOutlet weak var scannerView: QRScannerView!
     
     var delegate:BarcodeScannerViewControllerDelegate!
     @IBOutlet var labScanText: UILabel!
     
     var nextBtn : String =  ""
     var scanText : String =  ""
     @IBOutlet var btnNextText: UIButton!
     
        /*  {
          didSet {
               scannerView.delegate = self
          }
     }*/
     
     var qrData: QRData? = nil {
          didSet {
               if qrData != nil {
                    //self.performSegue(withIdentifier: "detailSeuge", sender: self)
                    print(qrData?.codeString)
                    
                    if(!items.contains((qrData?.codeString)!)){
                         items.append((qrData?.codeString)!)
                         do{
                              self.audioPlayer.play()
                         }catch {
                              print("Error getting the audio file")
                         }
                    }
                    
                    self.labCount.text = "\(self.items.count)"
                    print("size:\(items.count)")
                    
                    if !scannerView.isRunning {
                         scannerView.startScanning()
                    }
               }
          }
     }
     
     //var delegate:BarcodeScannerViewControllerDelegate!
     
     override func viewDidLoad() {
          super.viewDidLoad()
          
          // Do any additional setup after loading the view.
          
          scannerView.delegate = self
          
          UIApplication.shared.isIdleTimerDisabled = true
          
          self.navigationController?.navigationBar.barTintColor = hexStringToUIColor(hex: themeColor)
          self.navigationController?.navigationBar.tintColor = UIColor.white
          
          let rectShape = CAShapeLayer()
          rectShape.bounds = self.labCount.frame
          rectShape.position = self.labCount.center
          rectShape.path = UIBezierPath(roundedRect: self.labCount.bounds, byRoundingCorners: [.bottomLeft , .topLeft], cornerRadii: CGSize(width: 20, height: 20)).cgPath
          
          //self.labCount.layer.backgroundColor = hexStringToUIColor(hex: themeColor) as! CGColor
          //Here I'm masking the textView's layer with rectShape layer
          self.labCount.layer.mask = rectShape
          labScanText.text = scanText
          btnNextText.setTitle(nextBtn, for: .normal)
          
          let dev = Bundle.main.path(forResource: "beep_sound", ofType: "mp3")!
          //print(alertSound)
          
          // Removed deprecated use of AVAudioSessionDelegate protocol
          //try! AVAudioSession.sharedInstance().setCategory(AVAudioSession.Category.playback)
          //try! AVAudioSession.sharedInstance().setActive(true)
          
          audioPlayer = try! AVAudioPlayer(contentsOf: URL(fileURLWithPath: dev))
          audioPlayer.prepareToPlay()
     }
     
     override func viewWillAppear(_ animated: Bool) {
          super.viewWillAppear(animated)
          
          if !scannerView.isRunning {
               scannerView.startScanning()
          }
     }
     
     override func viewWillDisappear(_ animated: Bool) {
          super.viewWillDisappear(animated)
          
          UIApplication.shared.isIdleTimerDisabled = false
          
          if !scannerView.isRunning {
               scannerView.stopScanning()
          }
     }
     
     var isClicked:Bool = false
     
     @IBAction func NextClick(_ sender: UIButton) {
          print("NextClick")
          
          if(isClicked == false){
               
               isClicked = true
               
               let myGroup = DispatchGroup()
               
               myGroup.enter()
               //print("details...")
               if !scannerView.isRunning {
                    scannerView.stopScanning()
               }
               print("scan count:\(self.items.count)")
               let strr:String = jsonData(from: self.items)!
               print("scan json:\(strr)")
               
               self.delegate?.barcodeScannerViewController(self, didScanBarcodeWithResult: strr)
               print("buttonPressed")
               
               myGroup.leave()
               
               /*dispatch_group_notify(myGroup, dispatch_get_main_queue(), {
                self.dismiss(animated: false)
                })*/
               
               myGroup.notify(queue: DispatchQueue.main, execute: {
                    self.isClicked = false
                    self.dismiss(animated: false)
                    
               })
          }
     }
     
     func jsonData(from object:Any) -> String? {
          guard let data = try? JSONSerialization.data(withJSONObject: object, options: []) else {
               return nil
          }
          return String(data: data, encoding: String.Encoding.utf8)
     }
     
     @IBAction func backClick(_ sender: UIBarButtonItem) {
          
          print("backClick")
          if !scannerView.isRunning {
               scannerView.stopScanning()
          }
          self.delegate.barcodeScannerViewController(self, didFailWithErrorCode: "err")
          dismiss(animated: true)
     }
     
     /*
      // MARK: - Navigation
      
      // In a storyboard-based application, you will often want to do a little preparation before navigation
      override func prepare(for segue: UIStoryboardSegue, sender: Any?) {
      // Get the new view controller using segue.destination.
      // Pass the selected object to the new view controller.
      }
      */

     func hexStringToUIColor (hex:String) -> UIColor {
          var cString:String = hex.trimmingCharacters(in: .whitespacesAndNewlines).uppercased()
          
          if (cString.hasPrefix("#")) {
               cString.remove(at: cString.startIndex)
          }
          
          if ((cString.count) != 6) {
               return UIColor.gray
          }
          
          var rgbValue:UInt32 = 0
          Scanner(string: cString).scanHexInt32(&rgbValue)
          
          return UIColor(
               red: CGFloat((rgbValue & 0xFF0000) >> 16) / 255.0,
               green: CGFloat((rgbValue & 0x00FF00) >> 8) / 255.0,
               blue: CGFloat(rgbValue & 0x0000FF) / 255.0,
               alpha: CGFloat(1.0)
          )
     }
     
     func qrScanningDidStop() {
          //let buttonTitle = scannerView.isRunning ? "STOP" : "SCAN"
          //scanButton.setTitle(buttonTitle, for: .normal)
     }
     
     func qrScanningDidFail() {
          //presentAlert(withTitle: "Error", message: "Scanning Failed. Please try again")
          print("Scanning Failed. Please try again")
     }
     
     func qrScanningSucceededWithCode(_ str: String?) {
          self.qrData = QRData(codeString: str)
          print(self.qrData)
     }
}

/*extension OneDQrCodeViewController: QRScannerViewDelegate {
     func qrScanningDidStop() {
          let buttonTitle = scannerView.isRunning ? "STOP" : "SCAN"
          //scanButton.setTitle(buttonTitle, for: .normal)
     }
     
     func qrScanningDidFail() {
          //presentAlert(withTitle: "Error", message: "Scanning Failed. Please try again")
     }
     
     func qrScanningSucceededWithCode(_ str: String?) {
          self.qrData = QRData(codeString: str)
          print(self.qrData)
     }
     
     
     
}*/
